@@ -25,6 +25,7 @@ class ErioonClient:
         self.user_id = None
         self.login_metadata = None
         self.sas_tokens = {}
+        self.project_id = None
 
         parts = credential_string.split(":")
 
@@ -64,6 +65,7 @@ class ErioonClient:
         self.user_id = self.login_metadata.get("_id")
         self.cluster = self.login_metadata.get("cluster")
         self.database = self.login_metadata.get("database")
+        self.project_id = self.login_metadata.get("project_id")
 
         self.sas_tokens = {}
         for db_id, sas_info in self.login_metadata.get("sas_tokens", {}).items():
@@ -98,6 +100,12 @@ class ErioonClient:
 
         if response.status_code == 200:
             db_info = response.json()
+            db_project_id = db_info.get("project_id")
+            
+            if db_project_id != "all_projects":
+                if db_project_id != self.project_id:
+                    return "[ErioonClient] Invalid credentials for this project"
+            
             sas_info = self.sas_tokens.get(db_id)
             if not sas_info:
                 raise Exception(f"No login certificate token info for database id {db_id}")
