@@ -28,7 +28,8 @@ def ErioonLogin(credential_string):
 
     Example usage:
     >>> from erioon.auth import Auth
-    >>> client = Auth("<API_KEY>:<EMAIL>:<PASSWORD>")
+    >>> client = Auth("<API_KEY>")
+    >>> or client = Auth("<EMAIL>:<PASSWORD>")
     >>> print(client)  # prints user_id if successful or error message if not
     """
     return ErioonClient(credential_string)
